import { world, system } from "@minecraft/server";

const cropAges = {
    "minecraft:nether_wart": 3, 
};


const XP_ORB_CHANCE = 0.7;
const XP_ORB_COUNT = 1; 

let processedCrops = [];

system.run(function tick() {
    processedCrops = [];
    system.run(tick);
});

world.beforeEvents.playerInteractWithBlock.subscribe(({ block, player, itemStack }) => {
    
    if (itemStack?.typeId === "minecraft:bone_meal") return;

    const { dimension } = player;
    const blockType = block.typeId;
    const { x, y, z } = block.location;

    if (block.hasTag("minecraft:crop")) {
        const growth = block.permutation.getState("growth") || 0;

        if (growth === 7) {
            processCrop(dimension, block, x, y, z);
            maybeSpawnXPOrb(dimension, x, y, z);
        }
    }
    else if (cropAges[blockType] !== undefined) {
        const age = block.permutation.getState("age") || 0;

        if (age === cropAges[blockType]) {
            processCrop(dimension, block, x, y, z);
            maybeSpawnXPOrb(dimension, x, y, z);
        }
    }
});

function processCrop(dimension, block, x, y, z) {
    const blockKey = `${x}_${y}_${z}`;

    if (!processedCrops.includes(blockKey)) {
        dimension.runCommandAsync(`setblock ${x} ${y} ${z} ${block.typeId} destroy`);
        processedCrops.push(blockKey);
    }
}

function maybeSpawnXPOrb(dimension, x, y, z) {
    if (Math.random() < XP_ORB_CHANCE) {
        dimension.runCommandAsync(`summon xp_orb ${x} ${y + 0.5} ${z}`);
    }
}