import { world, system, Player } from "@minecraft/server";
import { ActionFormData, ModalFormData } from "@minecraft/server-ui";


const quests = [
    { id: 0, title: "Collect Raw Earthron Ore", item: "zc:rawron", amount: 3, icon: "textures/items/zc/zc_rawron.png" },
    { id: 1, title: "Craft Heavy Earthron Ore", item: "zc:heavyeo", amount: 2, icon: "textures/items/zc/zc_heavyeo.png" },
    { id: 2, title: "Smelt Heavy Earthron Ore for Ingot", item: "zc:earthron_ingot", amount: 2, icon: "textures/items/zc/zc_earthron_ingot.png" },
    { id: 3, title: "Forge Earthron Sword", item: "zc:earthron_sword", amount: 1, icon: "textures/items/zc/zc_earthron_sword.png" },
    { id: 4, title: "Craft Earthron Chestplate", item: "zc:earthron_chestplate", amount: 1, icon: "textures/items/zc/zc_earthron_chestplate.png" },
    { id: 5, title: "Craft Unstable Netheron", item: "zc:unneron_ore", amount: 3, icon: "textures/blocks/zc_unneron_ore.png" },
    { id: 6, title: "Place Unstable Netheron in Nether Then collect §eRaw Netheron", item: "zc:rawneth", amount: 1, icon: "textures/items/zc/zc_rawneth.png" },
    { id: 7, title: "Craft Netheron Ingot", item: "zc:heaneth_ingot", amount: 1, icon: "textures/items/zc/zc_heaneth_ingot.png" },
    { id: 8, title: "Forge Netheron Chestplate", item: "zc:netheron_chestplate", amount: 1, icon: "textures/items/zc/zc_netheron_chestplate.png" },
    { id: 9, title: "Craft unstable Endron ore", item: "zc:unnendron_ore", amount: 3, icon: "textures/blocks/zc_unnendron_ore.png" },
    { id: 10, title: "Place Unstable Endron in End Then collect §eRaw Endron", item: "zc:raw_endron", amount: 5, icon: "textures/items/zc/zc_raw_endron.png" },
    { id: 11, title: "Craft Endron Ingot", item: "zc:endron_ingot", amount: 5, icon: "textures/items/zc/zc_endron_ingot.png" },
    { id: 12, title: "Forge Endron Chestplate", item: "zc:endron_chestplate", amount: 1, icon: "textures/items/zc/zc_endron_chestplate.png" },
    { id: 13, title: "Kill Ender Dragon & collect Dragon Scale", item: "zc:enddragon_scal", amount: 10, icon: "textures/items/zc/zc_enddragon_scal.png" },
    { id: 14, title: "Kill Warden and collect Cave Start", item: "zc:uw_star", amount: 1, icon: "textures/items/zc/zc_uw_star.png" },
    { id: 15, title: "Craft Dragon Start", item: "zc:drago_star", amount: 1, icon: "textures/items/zc/zc_drago_star.png" },
    { id: 16, title: "Smelt Dragon Star & Collect Dragon Ingot", item: "zc:dragon_ingot", amount: 1, icon: "textures/items/zc/zc_dragon_ingot.png" } ,

];

function initScoreboard() {
    try {
        if (!world.scoreboard.getObjective("armourqust")) {
            world.scoreboard.addObjective("armourqust");
        }
    } catch (e) {
        console.warn("Scoreboard error: " + e);
    }
}

function getPlayerQuestScore(player) {
    try {
        const obj = world.scoreboard.getObjective("armourqust");
        if (!obj) return 0;
        return obj.getScore(player.scoreboardIdentity) ?? 0;
    } catch (e) {
        console.warn("Get score error: " + e);
        return 0;
    }
}

function setPlayerQuestScore(player, score) {
    try {
        const obj = world.scoreboard.getObjective("armourqust") || world.scoreboard.addObjective("armourqust", "Quests");
        obj.setScore(player.scoreboardIdentity, score);
    } catch (e) {
        console.warn("Set score error: " + e);
    }
}

async function showCompletedQuests(player) {
    try {
        const form = new ModalFormData().title("Completed Quests");
        const score = getPlayerQuestScore(player);
        const completed = quests.filter(q => q.id < score);

        if (completed.length === 0) {
            form.label("§7You haven't completed any quests yet.");
        } else {
            form.label(
                `§aCompleted: ${completed.length}/${quests.length}\n\n` +
                completed.map(q => `§2✓ ${q.title}`).join("\n")
            );
        }

        await form.show(player);
    } catch (e) {
        console.warn("Completed quests error: " + e);
    }
}
//menu
async function showQuestUI(player) {
    try {
        const form = new ActionFormData().title("Quest Menu");
        const currentQuestScore = getPlayerQuestScore(player);

        form.body(`§eYour Progress: ${currentQuestScore}/${quests.length} quests`);
        form.button("View Completed Quests", "textures/ui/confirm");

        
        const currentQuest = quests.find(q => q.id === currentQuestScore);
        if (currentQuest) {
            form.button(`${currentQuest.title}\n§1[Current]`, currentQuest.icon);
        }

        
        quests.forEach(q => {
            if (q.id > currentQuestScore) {
                form.button(`${q.title}\n§c[Locked]`, q.icon);
            }
        });

        const res = await form.show(player);
        if (res.canceled) return;

        if (res.selection === 0) {
            await showCompletedQuests(player);
            return;
        }

        const offset = 1;
        if (res.selection === offset && currentQuest) {
            player.sendMessage(`§a[Current Quest]: §f${currentQuest.title}\n§dAmount §f${currentQuest.amount}`);
        } else {
            player.sendMessage(`§cThis quest is locked. Complete earlier quests first.`);
        }

    } catch (e) {
        console.warn("Quest UI error: " + e);
        player.sendMessage("§cFailed to open quest menu.");
    }
}

function playSound(player, sound) {
    try {
        player.runCommand(`playsound ${sound} @s ~~~ 1 1`);
    } catch (e) {
        console.warn("Sound error: " + e);
    }
}


initScoreboard();


world.afterEvents.itemUse.subscribe(event => {
    const player = event.source;
    if (player instanceof Player && event.itemStack?.typeId === "zc:azq") {
        system.run(() => {
            showQuestUI(player).catch(console.warn);
        });
    }
});


system.runInterval(() => {
    for (const player of world.getAllPlayers()) {
        try {
            const currentScore = getPlayerQuestScore(player, "armourqust");
            if (currentScore >= quests.length) continue;

            const currentQuest = quests[currentScore];
            const inventory = player.getComponent("minecraft:inventory")?.container;
            if (!inventory) continue;

            
            let itemCount = 0;
            for (let i = 0; i < inventory.size; i++) {
                const item = inventory.getItem(i);
                if (item?.typeId === currentQuest.item) {
                    itemCount += item.amount;
                }
            }

            
            if (itemCount >= currentQuest.amount) {
                
                const verifiedScore = getPlayerQuestScore(player, "armourqust");
                if (verifiedScore !== currentScore) continue;

                
                player.runCommand(`tellraw @a {"rawtext":[{"text":"§6[Quest]§r ${player.name} completed: §a${currentQuest.title}"}]}`);
                
                
                const newScore = currentScore + 1;
                world.scoreboard.getObjective("armourqust").setScore(player.scoreboardIdentity, newScore);
                
                playSound(player, "random.levelup");

               

                
                if (newScore < quests.length) {
                    const nextQuest = quests[newScore];
                    player.runCommand(`tellraw @a {"rawtext":[{
                        "text":"§6[Quest]§r Next for ${player.name}: §e${nextQuest.title} §7(Need ${nextQuest.amount}x)"
                    }]}`);
                }
            }
        } catch (e) {
            console.warn(`Quest check error for ${player.name}: ${e}`);
        }
    }
}, 10);