import { world, system } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";

const ui = new ActionFormData()
    .title("Backpack Register")
    .body("Just Click On Register")
    .button("Register");

world.afterEvents.itemUse.subscribe(async (event) => {
    const { source, itemStack } = event;

    if (itemStack?.typeId !== "zc:bpris") return;

    try {
        const response = await ui.show(source);
        if (response.canceled || response.selection !== 0) return;

        const { x, y, z } = source.location;
        const { dimension } = source;
        const playerName = source.name;

        const pets = ["zc:bpet1", "zc:bpet2", "zc:bpet3", "zc:bpet4"];

        for (const pet of pets) {
            await dimension.runCommandAsync(`summon ${pet} ${x} ${y} ${z}`);
            await dimension.runCommandAsync(`tag @e[type=${pet},x=${x},y=${y},z=${z},r=1] add ${playerName}`);
        }

        await source.runCommandAsync(`give @s shulker_box 1`);
        await source.runCommandAsync(`clear @s zc:bpris 0 1`);

    } catch (error) {
        console.warn("Backpack Register Error:", error);
    }
});





const overworld = world.getDimension("overworld");

function teleportPet(petType, weaponItem, playerName) {
    overworld.runCommandAsync(
        `tp @e[type=${petType},tag=${playerName},c=1] @p[hasitem={item=${weaponItem},location=slot.weapon.mainhand},name=${playerName},c=1]`
    ).catch(error => console.warn(`Command failed: ${error}`));

    overworld.runCommandAsync(
        `tp @e[type=${petType},tag=${playerName},c=1] 10000 -104 10000`
    ).catch(error => console.warn(`Command failed: ${error}`));

    overworld.runCommandAsync(
        `tp @e[type=${petType},tag=${playerName},c=1] @p[hasitem={item=${weaponItem},location=slot.weapon.mainhand},name=${playerName},c=1]`
    ).catch(error => console.warn(`Command failed: ${error}`));
}

function mainTick() {
    for (const player of world.getPlayers()) {
        const playerName = player.name;

        // Pets
        teleportPet("zc:bpet1", "zc:wbp1", playerName);
        teleportPet("zc:bpet2", "zc:wbp2", playerName);
        teleportPet("zc:bpet3", "zc:wbp3", playerName);
        teleportPet("zc:bpet4", "zc:wbp4", playerName);

        overworld.runCommandAsync(
            `execute @a[tag=!lc] ~~~ tickingarea add 10000 -104 10000 10000 -103 10000 lc`
        ).catch(error => console.warn(`Command failed: ${error}`));

        overworld.runCommandAsync(
            `give @a[tag=!lc] zc:bpris 1 0`
        ).catch(error => console.warn(`Command failed: ${error}`));

        overworld.runCommandAsync(
            `tag @a[tag=!lc] add lc`
        ).catch(error => console.warn(`Command failed: ${error}`));
    }

    system.run(mainTick);
}

system.run(mainTick);
