import { world, system } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";

function showInfToggleUI(player) {
  const hasInf = player.hasTag("inf");
  const hasItg = player.hasTag("itg");

  const ui = new ModalFormData()
    .title("Settings")
    .toggle("Infinite Night Vision", hasInf)
    .toggle("Item Gathering", hasItg);

  ui.show(player).then(res => {
    if (res.canceled) return;

    const [infToggle, itgToggle] = res.formValues;

    if (infToggle && !hasInf) {
      player.runCommandAsync("tag @s add inf");
      player.runCommandAsync("say Night Vision Enabled");
    } else if (!infToggle && hasInf) {
      player.runCommandAsync("tag @s remove inf");
      player.runCommandAsync("effect @s night_vision 0");
      player.runCommandAsync("say Night Vision Disabled");
    }

    if (itgToggle && !hasItg) {
      player.runCommandAsync("tag @s add itg");
      player.runCommandAsync("say Item Gathering Enabled");
    } else if (!itgToggle && hasItg) {
      player.runCommandAsync("tag @s remove itg");
      player.runCommandAsync("say Item Gathering Disabled");
    }
  });
}

world.afterEvents.itemUse.subscribe(event => {
  const { source, itemStack } = event;
  if (!source || !itemStack) return;

  if (itemStack.typeId === "zc:inf") {
    showInfToggleUI(source);
  }
});

system.runInterval(() => {
  for (const player of world.getPlayers()) {
    if (player.hasTag("inf")) {
      player.runCommandAsync("effect @s night_vision 10 0 true");
    }
  }
}, 20); // every 1 second
