import { ActionFormData } from '@minecraft/server-ui';
import { world, system } from '@minecraft/server';

function loadPlayerLocations(player) {
    const savedLocations = player.getDynamicProperty('savedLocations');
    if (savedLocations) {
        return JSON.parse(savedLocations);
    }
    return [];
}

function savePlayerLocations(player, locations) {
    player.setDynamicProperty('savedLocations', JSON.stringify(locations));
}

function showTeleportUI(player, locations) {
    if (locations.length === 0) {
        player.sendMessage("§cYou have no saved locations.");
        return;
    }

    const ui = new ActionFormData()
        .title("§l§dTeleport Menu")
        .body("§7Select a location to teleport to:");

    locations.forEach(location => {
        ui.button(`§l§5${location.name}§r\n§8[${location.type}] ${location.public ? '§1(Public)' : '§4(Private)'}`, "textures/ui/mashup_world");
    });

    ui.show(player).then((response) => {
        if (!response.canceled) {
            const selectedLocation = locations[response.selection];
            if (player.level >= 2) {
                player.teleport(selectedLocation.position, { dimension: world.getDimension(selectedLocation.dimension) });
                player.addLevels(-2);
                player.sendMessage("§aTeleported successfully! 2 XP levels were deducted.");
            } else {
                player.sendMessage("§cYou need at least 2 XP levels to teleport to this location.");
            }
        }
    });
}

world.afterEvents.itemUse.subscribe((event) => {
    const { itemStack, source } = event;

    if (itemStack.typeId === "zc:telecom") {
        const locations = loadPlayerLocations(source);
        showTeleportUI(source, locations);
    }
});
